WhitePoint

Trait WhitePoint 

pub trait WhitePoint {
    // Required method
    fn get_xyz<Wp, T>() -> Xyz<Wp, T>
       where Wp: WhitePoint,
             T: Component + Float;
}
WhitePoint defines the Xyz color co-ordinates for a given white point.

A white point (often referred to as reference white or target white in technical documents) is a set of tristimulus values or chromaticity coordinates that serve to define the color “white” in image capture, encoding, or reproduction.

Custom white points can be easily defined on an empty struct with the tristimulus values and can be used in place of the ones defined in this library.

Required Methods

fn get_xyz<Wp, T>() -> Xyz<Wp, T>
where Wp: WhitePoint, T: Component + Float,

Get the Xyz chromacity co-ordinates for the white point.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors