Module frame

Module frame 

Items related to the Frame type, describing a single frame of graphics for a single window.

Re-exports

pub use self::raw::RawFrame;

Modules

raw
The lower-level “raw” frame type allowing to draw directly to the window’s swap chain image.

Structs

Frame
A Frame to which the user can draw graphics before it is presented to the display.
RenderData
Data specific to the intermediary textures.