pub struct Map { /* private fields */ }Expand description
A collection of mappings from font::Ids to rusttype::Fonts.
Implementations
Sourceimpl Map
impl Map
Sourcepub fn get(&self, id: Id) -> Option<&Font>
pub fn get(&self, id: Id) -> Option<&Font>
Borrow the rusttype::Font associated with the given font::Id.
Sourcepub fn insert(&mut self, font: Font) -> Id
pub fn insert(&mut self, font: Font) -> Id
Adds the given rusttype::Font to the Map and returns a unique Id for it.
Sourcepub fn insert_from_file<P>(&mut self, path: P) -> Result<Id, Error>
pub fn insert_from_file<P>(&mut self, path: P) -> Result<Id, Error>
Insert a single Font into the map by loading it from the given file path.