Module time

Module time 

Extensions and utilities for working with time.

Traits

DurationF64
An extension for the std::time::Duration type providing some simple methods for easy access to an f64 representation of seconds, ms, mins, hrs, and other units of time.