Items related to the App type and the application context in general.
See here for items relating to the event loop, device access, creating and managing windows, streams and more.
Structs
- App
- Each nannou application has a single App instance. This App represents the entire context of the application.
- Builder
- A nannou
Appbuilder. - Proxy
- A handle to the App that can be shared across threads. This may be used to “wake up” the App’s inner event loop.
- Sketch
Builder - A nannou
Sketchbuilder.
Enums
- Loop
Mode - The mode in which the App is currently running the event loop and emitting
Updateevents.
Functions
- find_
assets_ path - Attempt to find the assets directory path relative to the executable location.
- find_
project_ path - Attempt to find the assets directory path relative to the executable location.
Type Aliases
- EventFn
- The user function type for updating their model in accordance with some event.
- ExitFn
- The user function type allowing them to consume the
modelwhen the application exits. - ModelFn
- The user function type for initialising their model.
- Sketch
View Fn - A shorthand version of
ViewFnfor sketches where the user does not need a model. - Update
Fn - The user function type for updating the user model within the application loop.
- ViewFn
- The user function type for drawing their model to the surface of a single window.