Application, event loop and window event definitions and implementations.
- Event - the default application event type.
- winit::event::WindowEvent - events related to a single window.
- WindowEvent - a stripped-back, simplified, newcomer-friendly version of the raw, low-level winit event.
Structs
- Axis
Motion - Motion along some axis of a device e.g. joystick or gamepad.
- Keyboard
Input - Describes a keyboard input event.
- Modifiers
State - Represents the current state of the keyboard modifiers
- Touch
Event - The event associated with a touch at a single point.
- Touchpad
Pressure - Pressure on a touch pad.
- Update
- Update event, emitted on each pass of an application loop.
Enums
- Element
State - Describes the input state of a key.
- Event
- The default application Event type.
- Key
- Symbolic name for a keyboard key.
- Mouse
Button - Describes a button of a mouse controller.
- Mouse
Scroll Delta - Describes a difference in the mouse scroll wheel state.
- Touch
Phase - Describes touch-screen input state.
- Window
Event - A simplified version of winit’s
WindowEventtype to make it easier to get started.
Traits
- Loop
Event - Event types that are compatible with the nannou app loop.